==> tdesvn-trinity_14.0.8.orig.tar.xz: tdesvn-trinity-14.0.8/src/ksvnwidgets/depthselector.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Rajko Albrecht  ral@alwins-world.de             *
 *   http://tdesvn.alwins-world.de/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef DEPTHSELECTOR_H
#define DEPTHSELECTOR_H

#include "depthform.h"

#include "svnqttypes.hpp"

class TQCheckBox;

class DepthSelector: public DepthSettings {
    Q_OBJECT
  
public:
    DepthSelector(TQWidget *parent = 0, const char *name = 0);
    virtual ~DepthSelector();
    svn::Depth getDepth()const;
    void addItemWidget(TQWidget*);
    void hideDepth(bool hide);

protected:
    TQCheckBox*m_recurse;
};

#endif

==> tdesvn-trinity-14.0.10.tar.xz: tdesvn-trinity-14.0.10/src/ksvnwidgets/depthselector.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Rajko Albrecht  ral@alwins-world.de             *
 *   http://tdesvn.alwins-world.de/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef DEPTHSELECTOR_H
#define DEPTHSELECTOR_H

#include "depthform.h"

#include "svnqttypes.h"

class TQCheckBox;

class DepthSelector: public DepthSettings {
    Q_OBJECT
  
public:
    DepthSelector(TQWidget *parent = 0, const char *name = 0);
    virtual ~DepthSelector();
    svn::Depth getDepth()const;
    void addItemWidget(TQWidget*);
    void hideDepth(bool hide);

protected:
    TQCheckBox*m_recurse;
};

#endif
